@@ -7,10 +7,10 @@ import numpy as np
 import matplotlib.pyplot as plt
 
 # Owned Libraries
-from z2n import series
+from z2n.series import Series
 
 
-class Plot(series.Series):
+class Plot(Series):
     """
     A class to represent the plot of a time series.
 
@@ -100,11 +100,13 @@ class Plot(series.Series):
 
     def plot_background(self) -> None:
         """Create subplot of the background."""
+        plt.close()
         self.back.bins = self.data.bins
         if self.plots == 2:
             opt = click.prompt("Change the background [1] or remove it [2]")
             if opt == '1':
-                if not self.back.load_file():
+                if not self.back.set_time():
+                    plt.close()
                     self.back.set_periodogram()
                     self.add_background()
                     self.plot_figure()
@@ -114,43 +116,53 @@ class Plot(series.Series):
             else:
                 click.secho("Select '1' or '2'.", fg='red')
         else:
-            if not self.back.load_file():
+            if not self.back.set_time():
+                plt.close()
                 self.back.set_periodogram()
                 self.add_background()
                 self.plot_figure()
 
     def plot_periodogram(self) -> None:
         """Create plot of the periodogram."""
+        plt.close()
         if self.data.z2n.size:
             if click.confirm("Do you want to use another file"):
-                if not self.data.load_file():
+                if not self.data.set_time():
                     if not self.data.save_periodogram():
                         if self.plots == 2:
-                            self.back.bins = self.data.bins
-                            self.back.set_periodogram()
+                            if click.confirm("Keep the background"):
+                                self.back.bins = self.data.bins
+                                self.back.set_periodogram()
+                            else:
+                                self.rm_background()
                         self.change_forest()
+                        self.data.set_parameters()
                         self.data.get_parameters()
             else:
                 if click.confirm("Recalculate with different limits"):
                     if click.confirm("Drop the other bins"):
-                        self.change_whole()
-                        if self.plots == 2:
-                            self.back.bins = self.data.bins
-                            self.back.set_periodogram()
-                        self.change_forest()
-                        self.data.get_parameters()
+                        if not self.change_whole():
+                            if self.plots == 2:
+                                self.back.bins = self.data.bins
+                                self.back.set_periodogram()
+                            self.change_forest()
+                            self.data.set_parameters()
+                            self.data.get_parameters()
                     else:
-                        self.change_region()
-                        self.change_forest()
-                        self.data.get_parameters()
+                        if not self.change_region():
+                            self.change_forest()
+                            self.data.set_parameters()
+                            self.data.get_parameters()
         else:
-            if not self.data.load_file():
+            if not self.data.set_time():
                 if not self.data.save_periodogram():
                     self.change_forest()
+                    self.data.set_parameters()
                     self.data.get_parameters()
 
     def change_whole(self) -> None:
         """Change limits on the whole periodogram."""
+        flag = 0
         click.secho("This will recalculate the periodogram.", fg='yellow')
         self.plot_figure()
         if click.confirm("Are the new limits selected"):
@@ -159,10 +171,15 @@ class Plot(series.Series):
             self.data.fmax = self.axis[1]
             self.data.set_delta()
             self.data.bins = np.arange(self.fmin, self.fmax, self.delta)
+            plt.close()
             self.data.set_periodogram()
+        else:
+            flag = 1
+        return flag
 
-    def change_region(self) -> None:
+    def change_region(self) -> int:
         """Change limits on a periodogram region."""
+        flag = 0
         click.secho("This will recalculate the periodogram.", fg='yellow')
         self.plot_figure()
         if click.confirm("Is the region selected"):
@@ -176,6 +193,7 @@ class Plot(series.Series):
             self.set_delta()
             self.bins = np.arange(self.fmin, self.fmax, self.delta)
             self.time = self.data.time
+            plt.close()
             self.set_periodogram()
             size = (self.data.bins.size - (up - low)) + self.bins.size
             middle = low + self.bins.size
@@ -189,6 +207,9 @@ class Plot(series.Series):
             tempy[middle:] = self.data.z2n[up:]
             self.data.bins = tempx
             self.data.z2n = tempy
+        else:
+            flag = 1
+        return flag
 
     def change_forest(self) -> None:
         """Select regions of uncertainty."""
