@@ -28,8 +28,6 @@ class Series:
     > An arrray that represents the frequency bins.
     * `z2n : np.array`
     > An arrray that represents the periodogram.
-    * `harmonics : int`
-    > An integer that represents the number of harmonics.
     * `oversample : int`
     > An integer that represents the oversample factor.
     * `fmin : float`
@@ -68,7 +66,6 @@ class Series:
         self.time = np.array([])
         self.bins = np.array([])
         self.z2n = np.array([])
-        self.harmonics = 1
         self.fmin = 0
         self.fmax = 0
         self.delta = 0
@@ -109,24 +106,30 @@ class Series:
 
     def set_format(self) -> None:
         """Change the file format."""
-        self.format = click.prompt("Which format [ascii, csv, fits]")
+        self.format = click.prompt("Which format [ascii, csv, fits, hdf5]")
 
     def get_time(self) -> np.array:
         """Return the time series."""
         click.secho(f"{self.time.size} time values.", fg='cyan')
         return self.time
 
-    def set_time(self) -> None:
+    def set_time(self) -> int:
         """Change the time series."""
-        self.load_file()
+        flag = 0
+        if not self.load_file():
+            self.time = self.time.astype(self.time.dtype.name)
+        else:
+            flag = 1
+        return flag
 
     def get_bins(self) -> np.array:
         """Return the frequency bins."""
         click.secho(f"{self.bins.size} frequency bins.", fg='cyan')
         return self.bins
 
-    def set_bins(self) -> None:
+    def set_bins(self) -> int:
         """Change the frequency bins."""
+        flag = 1
         self.set_sampling()
         if click.confirm("Do you want to use the Nyquist frequency"):
             self.fmin = self.sampling * 2
@@ -143,8 +146,16 @@ class Series:
             self.get_fmin()
             self.get_fmax()
             self.get_delta()
-        self.bins = np.arange(self.fmin, self.fmax, self.delta)
-        click.secho('Frequency bins set.', fg='green')
+        block = (self.fmax - self.fmin) / np.array(self.delta)
+        nbytes = np.array(self.delta).dtype.itemsize * block
+        click.secho(
+            f"Computation memory {nbytes * 10e-6} MB", fg='yellow')
+        if click.confirm("Run the program with these values"):
+            self.bins = np.arange(self.fmin, self.fmax, self.delta)
+            click.secho('Frequency bins set.', fg='green')
+            self.get_bins()
+            flag = 0
+        return flag
 
     def get_periodogram(self) -> np.array:
         """Return the periodogram."""
@@ -153,7 +164,6 @@ class Series:
 
     def set_periodogram(self) -> None:
         """Change the periodogram."""
-        self.time = self.time.astype('float64')
         self.z2n = np.zeros(self.bins.size)
         stats.periodogram(self)
         click.secho('Periodogram calculated.', fg='green')
@@ -198,16 +208,6 @@ class Series:
         self.oversample = click.prompt("Oversample factor", type=float)
         click.secho('Oversample factor set.', fg='green')
 
-    def get_harmonics(self) -> float:
-        """Return the number of harmonics."""
-        click.secho(f"Number of harmonics: {self.harmonics}", fg='cyan')
-        return self.harmonics
-
-    def set_harmonics(self) -> None:
-        """Change the number of harmonics."""
-        self.harmonics = click.prompt("Number of harmonics", type=float)
-        click.secho('Harmonics set.', fg='green')
-
     def get_observation(self) -> float:
         """Return the period of observation."""
         click.secho(f"Period of observation: {self.observation} s", fg='cyan')
@@ -300,25 +300,28 @@ class Series:
 
     def load_file(self) -> int:
         """Load a input file."""
+        flag = 0
         self.set_format()
         if self.format == 'ascii':
             self.set_input()
             file.load_ascii(self)
             click.secho("File loaded.", fg='green')
-            return 0
         elif self.format == 'csv':
             self.set_input()
             file.load_csv(self)
             click.secho("File loaded.", fg='green')
-            return 0
         elif self.format == 'fits':
             self.set_input()
             file.load_fits(self)
             click.secho("File loaded.", fg='green')
-            return 0
+        elif self.format == 'hdf5':
+            self.set_input()
+            file.load_hdf5(self)
+            click.secho("File loaded.", fg='green')
         else:
             click.secho(f"{self.format} format not supported.", fg='red')
-            return 1
+            flag = 1
+        return flag
 
     def save_file(self) -> None:
         """Save a output file."""
@@ -335,42 +338,50 @@ class Series:
             self.set_output()
             file.save_fits(self)
             click.secho(f"Saved at {self.output}.{self.format}", fg='green')
+        elif self.format == 'hdf5':
+            self.set_output()
+            file.save_hdf5(self)
+            click.secho(f"Saved at {self.output}.{self.format}", fg='green')
         else:
             click.secho(f"{self.format} format not supported.", fg='red')
 
     def load_periodogram(self) -> int:
         """Plot the periodogram from a file."""
+        flag = 0
         self.set_format()
         if self.format == 'ascii':
             self.set_input()
             file.plot_ascii(self)
             click.secho("File loaded.", fg='green')
-            return 0
         elif self.format == 'csv':
             self.set_input()
             file.plot_csv(self)
             click.secho("File loaded.", fg='green')
-            return 0
         elif self.format == 'fits':
             self.set_input()
             file.plot_fits(self)
             click.secho("File loaded.", fg='green')
-            return 0
+        elif self.format == 'hdf5':
+            self.set_input()
+            file.plot_hdf5(self)
+            click.secho("File loaded.", fg='green')
         else:
             click.secho(f"{self.format} format not supported.", fg='red')
-            return 1
+            flag = 1
+        return flag
 
     def save_periodogram(self) -> int:
         """Calculate the Z2n statistic."""
-        self.set_bins()
-        if click.confirm("Run the program with these values"):
-            if not self.set_periodogram():
-                self.set_parameters()
-                return 0
-            else:
-                return 1
+        flag = 0
+        if not self.set_bins():
+            try:
+                self.set_periodogram()
+            except:
+                click.secho("Error calculating the periodogram.", fg='red')
+                flag = 1
         else:
-            return 1
+            flag = 1
+        return flag
 
     def get_parameters(self) -> None:
         """Return the parameters used on the statistic."""
@@ -380,7 +391,6 @@ class Series:
         self.get_fmin()
         self.get_fmax()
         self.get_delta()
-        self.get_bins()
         self.get_periodogram()
         self.get_potency()
         self.get_forest()
